@@ -2,7 +2,7 @@
 
 /**
   * SquirrelMail Mail Alias Plugin
-  * Copyright (C) 2004 Graeme C Neatham <graeme@promptpost.com>
+  * Copyright (C) 2004,2005 Graeme C Neatham <graeme@promptpost.com>
   * This program is licensed under GPL. See COPYING for details
   *
   */
@@ -28,6 +28,6 @@ function mail_alias_optpage_register_block() {
 
 function mail_alias_version() {
 
-   return '1.6';
+   return '2.0.0';
 }
 ?>
